{
    "scan": {
        "analyzer-version-clippy": "1.84.0",
        "analyzer-version-cppcheck": "2.16.2",
        "analyzer-version-gcc": "15.0.1",
        "analyzer-version-gcc-analyzer": "15.0.1",
        "analyzer-version-shellcheck": "0.10.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-185.us-west-2.compute.internal",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "tmt-1.42.0.dev16+g6aa1f0b8-main",
        "store-results-to": "/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz",
        "time-created": "2025-01-27 16:12:03",
        "time-finished": "2025-01-27 16:13:37",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'gcc,shellcheck,clippy,unicontrol,cppcheck' '-o' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.src.rpm'",
        "tool-version": "csmock-3.8.0-1.el9"
    },
    "defects": [
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "d50cf8f3c55bd23a64ed8998028dd8e4bb336845",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/usr/share/doc/tmt/examples/convert/runtest.sh",
                    "line": 20,
                    "column": 22,
                    "h_size": 7,
                    "event": "warning[SC2154]",
                    "message": "TmpDir is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   18|           rlAssertRpm $PACKAGE",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   19|           rlRun \"TmpDir=\\$(mktemp -d)\" 0 \"Creating tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   20|->         rlRun \"pushd $TmpDir\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   21|   \t\trlRun \"set -o pipefail\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   22|       rlPhaseEnd",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "22a71c6d67d785a3240e4c3c8262eb7134dc46b1",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/usr/share/doc/tmt/examples/wow/full/test.sh",
                    "line": 8,
                    "column": 22,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "tmp is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    6|           rlRun \"tmp=\\$(mktemp -d)\" 0 \"Create tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    7|           rlRun \"run=/var/tmp/tmt/mini\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    8|->         rlRun \"pushd $tmp\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    9|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   10|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "9a4655d1914fc69e312caae00f7f56ac99b6321a",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/usr/share/doc/tmt/examples/wow/full/test.sh",
                    "line": 22,
                    "column": 27,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "run is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   20|           report=\"$BEAKERLIB_COMMAND_REPORT_RESULT\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   21|           export BEAKERLIB_COMMAND_REPORT_RESULT=/bin/true",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   22|->         rlRun \"tmt run -i $run -av \\",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   23|               prepare -h install -c psss/tmt -p tmt+all \\",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   24|               plan --name 'plans|container|virtual'\"",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "745591ecbc4bc970def03cd7d12e9f16a5cb931a",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/usr/share/doc/tmt/examples/wow/mini/test.sh",
                    "line": 8,
                    "column": 22,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "tmp is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    6|           rlRun \"tmp=\\$(mktemp -d)\" 0 \"Create tmp directory\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    7|           rlRun \"run=/var/tmp/tmt/mini\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    8|->         rlRun \"pushd $tmp\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "    9|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   10|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "SHELLCHECK_WARNING",
            "cwe": 457,
            "language": "shell",
            "tool": "shellcheck",
            "hash_v1": "d4d6af98275e7e8e9a9f98f33b8fda61453d49bc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/usr/share/doc/tmt/examples/wow/mini/test.sh",
                    "line": 14,
                    "column": 27,
                    "h_size": 4,
                    "event": "warning[SC2154]",
                    "message": "run is referenced but not assigned.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   12|           rlRun \"dnf install -y tmt\" 0 \"Install the base tmt package\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   13|           rlRun \"tmt init -t base\" 0 \"Initialize with the base template\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   14|->         rlRun \"tmt run -i $run -av provision -h local\" 0 \"Run the example\"",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   15|       rlPhaseEnd",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   16|   ",
                    "verbosity_level": 1
                }
            ]
        }
    ]
}
