{
    "scan": {
        "analyzer-version-clippy": "1.84.0",
        "analyzer-version-cppcheck": "2.16.2",
        "analyzer-version-gcc": "15.0.1",
        "analyzer-version-gcc-analyzer": "15.0.1",
        "analyzer-version-shellcheck": "0.10.0",
        "analyzer-version-unicontrol": "0.0.2",
        "diffbase-analyzer-version-clippy": "1.84.0",
        "diffbase-analyzer-version-cppcheck": "2.16.2",
        "diffbase-analyzer-version-gcc": "15.0.1",
        "diffbase-analyzer-version-gcc-analyzer": "15.0.1",
        "diffbase-analyzer-version-shellcheck": "0.10.0",
        "diffbase-analyzer-version-unicontrol": "0.0.2",
        "diffbase-enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "diffbase-exit-code": 0,
        "diffbase-host": "ip-172-16-1-185.us-west-2.compute.internal",
        "diffbase-mock-config": "fedora-rawhide-x86_64",
        "diffbase-project-name": "tmt-1.42.0.dev16+g6aa1f0b8-main",
        "diffbase-store-results-to": "/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz",
        "diffbase-time-created": "2025-01-27 16:12:03",
        "diffbase-time-finished": "2025-01-27 16:13:37",
        "diffbase-tool": "csmock",
        "diffbase-tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'gcc,shellcheck,clippy,unicontrol,cppcheck' '-o' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.src.rpm'",
        "diffbase-tool-version": "csmock-3.8.0-1.el9",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-185.us-west-2.compute.internal",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "tmt-1.42.0.dev16+g6aa1f0b8-main",
        "store-results-to": "/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz",
        "time-created": "2025-01-27 16:12:03",
        "time-finished": "2025-01-27 16:13:37",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'gcc,shellcheck,clippy,unicontrol,cppcheck' '-o' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '/tmp/tmpcjf6ji_6/tmt-1.42.0.dev16+g6aa1f0b8-main.src.rpm'",
        "tool-version": "csmock-3.8.0-1.el9"
    },
    "defects": []
}
